import { KMS } from 'aws-sdk';

var __awaiter = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const kms = new KMS();
const isBase64 = /^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{4}|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)$/;
const dictionary = new Map();
function decrypt(ciphertext) {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield kms
            .decrypt({ CiphertextBlob: Buffer.from(ciphertext, 'base64') })
            .promise();
        const plaintext = result.Plaintext ? result.Plaintext.toString() : ciphertext;
        return dictionary.set(ciphertext, plaintext) && plaintext;
    });
}
var kmsDecrypt = (ciphertext) => (process.env.DISABLE_AWS_KMS_THINGY && ciphertext) ||
    (!isBase64.test(ciphertext) && ciphertext) ||
    dictionary.get(ciphertext) ||
    decrypt(ciphertext);

var __awaiter$1 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const kms$1 = new KMS();
const dictionary$1 = new Map();
function encrypt({ plaintext, keyId, }) {
    return __awaiter$1(this, void 0, void 0, function* () {
        const result = yield kms$1
            .encrypt({ KeyId: keyId, Plaintext: plaintext })
            .promise();
        const ciphertext = result.CiphertextBlob
            ? result.CiphertextBlob.toString('base64')
            : plaintext;
        return dictionary$1.set(plaintext, ciphertext) && ciphertext;
    });
}
var kmsEncrypt = ({ plaintext, keyId, }) => (process.env.DISABLE_AWS_KMS_THINGY && plaintext) ||
    dictionary$1.get(keyId + plaintext) ||
    encrypt({ plaintext, keyId });

const encrypt$1 = (parameters) => 'plaintext' in parameters
    ? kmsEncrypt(parameters)
    : Promise.all(parameters.map(kmsEncrypt));
const decrypt$1 = (ciphertext) => typeof ciphertext === 'string'
    ? kmsDecrypt(ciphertext)
    : Promise.all(ciphertext.map(kmsDecrypt));

export { encrypt$1 as encrypt, decrypt$1 as decrypt };
