#!/usr/bin/env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as readline from 'readline';
import * as lib from './';
const COLUMNS = process.stdout.columns || 32;
const askQuestion = (question, prompt = '→', sensitive = false) => {
    const line = readline.createInterface({
        input: process.stdin,
        output: process.stdout,
    });
    return new Promise(resolve => line.question(`\n${question}:\n\n${prompt} `, answer => !line.close() &&
        (sensitive
            ? !readline.moveCursor(process.stdin, 0, -1) &&
                !readline.clearLine(process.stdin, 0) &&
                !console.log(prompt + '  ' + '*'.repeat(answer.length))
            : true) &&
        resolve(answer.trim())));
};
const printUsageText = () => console.info(`
Usage: aws-kms-thingy [command]

Commands:
  - encrypt       Encrypt a string with an AWS KMS key
  - decrypt       Decrypt ciphertext encrypted with AWS KMS
`);
const prettyResult = (title, text) => !console.log(`\n${'〰️'.repeat((COLUMNS - (title.length + 2)) / 4)} ${title} ${'〰️'.repeat((COLUMNS - (title.length + 2)) / 4)}\n`, text, `\n${'〰️'.repeat(COLUMNS / 2)}\n`) && text;
function encrypt() {
    return __awaiter(this, void 0, void 0, function* () {
        const keyId = process.env.AWS_KMS_KEY_ARN ||
            (yield askQuestion('Please enter AWS KMS Key ARN to use'));
        const plaintext = yield askQuestion('Enter plain text to encrypt', '🔓', true);
        const result = (yield lib.encrypt({ keyId, plaintext }));
        return prettyResult('🔐 Encrypted', result);
    });
}
function decrypt() {
    return __awaiter(this, void 0, void 0, function* () {
        const ciphertext = yield askQuestion('Enter ciphertext to decrypt', '🔐');
        const result = (yield lib.decrypt(ciphertext));
        return prettyResult('🔓 Decrypted', result);
    });
}
export function main([, , action] = process.argv) {
    return __awaiter(this, void 0, void 0, function* () {
        const actions = {
            decrypt,
            encrypt,
        };
        return action && action in actions
            ? !console.log(`aws-kms-thingy ${action}`) && actions[action]()
            : printUsageText();
    });
}
main().catch(console.error);
